@@ -76,7 +76,7 @@ main(void)
 	struct cmsghdr *cmsg;
 	struct sctp_sndrcvinfo *sinfo;
         struct iovec out_iov;
-        u_int8_t *message = "hello, world!\n";
+        char *message = "hello, world!\n";
         int error;
 	int pf_class, af_family;
 	uint32_t ppid;
@@ -97,8 +97,9 @@ main(void)
 	struct sctp_sndrcvinfo get_accept_assoc_dflt_param; 
 	struct sctp_paddrinfo pinfo;
 	int dflt_pathmaxrxt;
-	int optlen, addrlen;
+	socklen_t optlen, addrlen;
 	struct sctp_status status;
+	struct sctp_assoc_value value;
 
         /* Rather than fflush() throughout the code, set stdout to
 	 * be unbuffered.
@@ -490,6 +491,7 @@ main(void)
 	/* Change the default parameters for this endpoint (socket) */
 	paddrparams.spp_hbinterval = 1000;
 	paddrparams.spp_pathmaxrxt = dflt_pathmaxrxt+1;
+	paddrparams.spp_sackdelay = 100;
 	test_setsockopt(udp_svr_sk, SCTP_PEER_ADDR_PARAMS, &paddrparams,
 							sizeof(paddrparams));
 
@@ -503,6 +505,28 @@ main(void)
 		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
 			 "mismatch");
 
+	value.assoc_id = 0;
+	optlen = sizeof(value);
+	test_getsockopt(udp_svr_sk, SCTP_DELAYED_ACK_TIME, &value,
+								&optlen);
+	if (value.assoc_value != 100)
+		tst_brkm(TBROK, tst_exit, "getsockopt(SCTP_DELAYED_ACK_TIME) "
+			 "mismatch");
+
+	value.assoc_id    = 0;
+	value.assoc_value = 250;
+	test_setsockopt(udp_svr_sk, SCTP_DELAYED_ACK_TIME, &value,
+							sizeof(value));
+	optlen = sizeof(paddrparams);
+	test_getsockopt(udp_svr_sk, SCTP_PEER_ADDR_PARAMS, &paddrparams,
+								&optlen);
+	if (paddrparams.spp_sackdelay != 250)
+		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_DELAYED_ACK_TIME) "
+			 "mismatch");
+
+	tst_resm(TPASS, "setsockopt(SCTP_DELAYED_ACK_TIME)");
+
+
 	/* Ensure that prior defaults are preserved for a new endpoint */
 	udp_clt_sk = test_socket(pf_class, SOCK_SEQPACKET, IPPROTO_SCTP);
 	optlen = sizeof(paddrparams);
@@ -518,10 +542,10 @@ main(void)
 	tst_resm(TPASS, "setsockopt(SCTP_PEER_ADDR_PARAMS)");
 
        	/* Invalid assoc id */
-	set_udp_sk_dflt_param.sinfo_assoc_id = 1234;
+	paddrparams.spp_assoc_id = 1234;
         error = setsockopt(udp_clt_sk, SOL_SCTP, SCTP_PEER_ADDR_PARAMS,
-			   &set_udp_sk_dflt_param,
-			   sizeof(set_udp_sk_dflt_param));
+			   &paddrparams,
+			   sizeof(paddrparams));
 	if ((-1 != error) || (EINVAL != errno))
 		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
 			 "invalid associd error:%d, errno:%d\n",
@@ -558,6 +582,157 @@ main(void)
 	tst_resm(TPASS, "setsockopt(SCTP_PEER_ADDR_PARAMS) - "
 		 "one-to-many style valid associd valid address");
 
+	paddrparams.spp_assoc_id = sac->sac_assoc_id;
+	memcpy(&paddrparams.spp_address, &udp_svr_loop, sizeof(udp_svr_loop));
+	paddrparams.spp_hbinterval = 1000;
+	paddrparams.spp_pathmaxrxt = dflt_pathmaxrxt+1;
+	
+        error = setsockopt(udp_clt_sk, SOL_SCTP, SCTP_PEER_ADDR_PARAMS,
+			   &paddrparams,
+			   sizeof(paddrparams));
+	if ((-1 != error) || (EINVAL != errno))
+		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+			 "invalid transport error:%d, errno:%d\n",
+			 error, errno);
+
+	tst_resm(TPASS, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+		 "- one-to-many style invalid transport");
+
+	paddrparams.spp_assoc_id = sac->sac_assoc_id;
+	memcpy(&paddrparams.spp_address, &udp_clt_loop, sizeof(udp_clt_loop));
+	paddrparams.spp_hbinterval = 1000;
+	paddrparams.spp_pathmaxrxt = dflt_pathmaxrxt+1;
+
+        error = setsockopt(udp_clt_sk, SOL_SCTP, SCTP_PEER_ADDR_PARAMS,
+			   &paddrparams,
+			   sizeof(paddrparams) - 1);
+	if ((-1 != error) || (EINVAL != errno))
+		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+			 "invalid parameter length error:%d, errno:%d\n",
+			 error, errno);
+
+	tst_resm(TPASS, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+		 "- one-to-many style invalid parameter length");
+
+        error = setsockopt(udp_clt_sk, SOL_SCTP, SCTP_DELAYED_ACK_TIME,
+			   &value,
+			   sizeof(value) - 1);
+	if ((-1 != error) || (EINVAL != errno))
+		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_DELAYED_ACK_TIME) "
+			 "invalid parameter length error:%d, errno:%d\n",
+			 error, errno);
+
+	tst_resm(TPASS, "setsockopt(SCTP_DELAYED_ACK_TIME) "
+		 "- one-to-many style invalid parameter length");
+
+	memset(&paddrparams, 0, sizeof(paddrparams));
+	paddrparams.spp_assoc_id = sac->sac_assoc_id;
+	memcpy(&paddrparams.spp_address, &udp_clt_loop, sizeof(udp_clt_loop));
+	paddrparams.spp_sackdelay = 501;
+
+        error = setsockopt(udp_clt_sk, SOL_SCTP, SCTP_PEER_ADDR_PARAMS,
+			   &paddrparams,
+			   sizeof(paddrparams));
+	if ((-1 != error) || (EINVAL != errno))
+		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+			 "invalid sack delay error:%d, errno:%d\n",
+			 error, errno);
+
+	tst_resm(TPASS, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+		 "- one-to-many style invalid sack delay");
+
+	value.assoc_id    = sac->sac_assoc_id;
+	value.assoc_value = 501;
+
+        error = setsockopt(udp_clt_sk, SOL_SCTP, SCTP_DELAYED_ACK_TIME,
+			   &value,
+			   sizeof(value));
+	if ((-1 != error) || (EINVAL != errno))
+		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_DELAYED_ACK_TIME) "
+			 "invalid sack delay error:%d, errno:%d\n",
+			 error, errno);
+
+	tst_resm(TPASS, "setsockopt(SCTP_DELAYED_ACK_TIME) "
+		 "- one-to-many style invalid sack delay");
+
+	memset(&paddrparams, 0, sizeof(paddrparams));
+	paddrparams.spp_assoc_id = sac->sac_assoc_id;
+	memcpy(&paddrparams.spp_address, &udp_clt_loop, sizeof(udp_clt_loop));
+	paddrparams.spp_pathmtu = 511;
+
+        error = setsockopt(udp_clt_sk, SOL_SCTP, SCTP_PEER_ADDR_PARAMS,
+			   &paddrparams,
+			   sizeof(paddrparams));
+	if ((-1 != error) || (EINVAL != errno))
+		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+			 "invalid path MTU error:%d, errno:%d\n",
+			 error, errno);
+
+	tst_resm(TPASS, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+		 "- one-to-many style invalid path MTU");
+
+	memset(&paddrparams, 0, sizeof(paddrparams));
+	paddrparams.spp_assoc_id = sac->sac_assoc_id;
+	memcpy(&paddrparams.spp_address, &udp_clt_loop, sizeof(udp_clt_loop));
+	paddrparams.spp_flags = SPP_HB_ENABLE | SPP_HB_DISABLE;
+
+        error = setsockopt(udp_clt_sk, SOL_SCTP, SCTP_PEER_ADDR_PARAMS,
+			   &paddrparams,
+			   sizeof(paddrparams));
+	if ((-1 != error) || (EINVAL != errno))
+		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+			 "invalid hb enable flags error:%d, errno:%d\n",
+			 error, errno);
+
+	tst_resm(TPASS, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+		 "- one-to-many style invalid hb enable flags");
+
+	memset(&paddrparams, 0, sizeof(paddrparams));
+	paddrparams.spp_assoc_id = sac->sac_assoc_id;
+	memcpy(&paddrparams.spp_address, &udp_clt_loop, sizeof(udp_clt_loop));
+	paddrparams.spp_flags = SPP_PMTUD_ENABLE | SPP_PMTUD_DISABLE;
+
+        error = setsockopt(udp_clt_sk, SOL_SCTP, SCTP_PEER_ADDR_PARAMS,
+			   &paddrparams,
+			   sizeof(paddrparams));
+	if ((-1 != error) || (EINVAL != errno))
+		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+			 "invalid PMTU discovery enable flags error:%d, errno:%d\n",
+			 error, errno);
+
+	tst_resm(TPASS, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+		 "- one-to-many style invalid PMTU discovery enable flags");
+
+	memset(&paddrparams, 0, sizeof(paddrparams));
+	paddrparams.spp_assoc_id = sac->sac_assoc_id;
+	memcpy(&paddrparams.spp_address, &udp_clt_loop, sizeof(udp_clt_loop));
+	paddrparams.spp_flags = SPP_SACKDELAY_ENABLE | SPP_SACKDELAY_DISABLE;
+
+        error = setsockopt(udp_clt_sk, SOL_SCTP, SCTP_PEER_ADDR_PARAMS,
+			   &paddrparams,
+			   sizeof(paddrparams));
+	if ((-1 != error) || (EINVAL != errno))
+		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+			 "invalid sack delay enable flags error:%d, errno:%d\n",
+			 error, errno);
+
+	tst_resm(TPASS, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+		 "- one-to-many style invalid sack delay enable flags");
+
+	memset(&paddrparams, 0, sizeof(paddrparams));
+	paddrparams.spp_flags = SPP_HB_DEMAND;
+
+        error = setsockopt(udp_clt_sk, SOL_SCTP, SCTP_PEER_ADDR_PARAMS,
+			   &paddrparams,
+			   sizeof(paddrparams));
+	if ((-1 != error) || (EINVAL != errno))
+		tst_brkm(TBROK, tst_exit, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+			 "invalid hb demand error:%d, errno:%d\n",
+			 error, errno);
+
+	tst_resm(TPASS, "setsockopt(SCTP_PEER_ADDR_PARAMS) "
+		 "- one-to-many style invalid hb demand");
+
 	close(udp_svr_sk);
 	close(udp_clt_sk);
 
